@@ -404,7 +404,7 @@ class Element:
                 return parent
             try:
                 parent = parent.parent()
-            except:
+            except Exception:
                 break
 
         return None
@@ -431,7 +431,9 @@ class ImportElement(Element):
 
 
 class Types(Collection):
-    default = lambda self, k: k.targetNamespace
+
+    def default(self, k):
+        return k.targetNamespace
 
     def __init__(self, parent):
         Collection.__init__(self, parent)
@@ -759,7 +761,7 @@ class MessageRole(Element):
                 return parent
             try:
                 parent = parent.parent()
-            except:
+            except Exception:
                 break
 
         return None
@@ -1485,9 +1487,9 @@ def FindExtensions(object, kind, t_type=type(())):
         # result = []
         namespaceURI, name = kind
         return [item for item in object.extensions
-                if hasattr(item, 'nodeType')
-                and DOM.nsUriMatch(namespaceURI, item.namespaceURI)
-                and item.name == name]
+                if hasattr(item, 'nodeType') and
+                DOM.nsUriMatch(namespaceURI, item.namespaceURI) and
+                item.name == name]
     return [item for item in object.extensions if isinstance(item, kind)]
 
 
@@ -1614,7 +1616,7 @@ class HeaderInfo(ParameterInfo):
     actor = None
 
 
-def callInfoFromWSDL(self, port, name):
+def callInfoFromWSDL(port, name):
     logger = logging.getLogger(__name__)
     """Return a SOAPCallInfo given a WSDL port and operation name."""
     wsdl = port.getService().getWSDL()
@@ -1686,9 +1688,9 @@ def callInfoFromWSDL(self, port, name):
         try:
             message = messages[operation.output.message]
         except KeyError:
-            if self.strict:
+            if wsdl.strict:
                 raise RuntimeError(
-                    "Recieved message not defined in the WSDL schema: %s" %
+                    "Received message not defined in the WSDL schema: %s" %
                     operation.output.message)
             else:
                 message = wsdl.addMessage(operation.output.message)
